==> xd3d-8.2.3.tar.gz: xd3d-8.2.3/src/X/gslss.f <==
      subroutine gslss(ifonte)
      INCLUDE 'Parametres.f'
      character*132 lafonte,fontes(6*nfontes_de_base)
      integer lfont(6*nfontes_de_base)
      data fontes /
     & '6x13','*-courier-bold-r-*-17-*-iso*',
     & '*-times-bold-r-*-24-*-iso*','*-times-bold-r-*-18-*-iso*',
     & 2*'*-times-bold-r-*-34-*-iso*','*-times-bold-r-*-14-*-iso*',
     & '*-helvetica-bold-r-*-14-*-iso*','*-helvetica-bold-o-*-14-*-iso*'
     & ,'5x8','7x14b*','9x15b*','*-helvetica-bold-r-*-12-*-iso*',
     & '*-helvetica-bold-o-*-12-*-iso*',
     & '*-helvetica-bold-r-*-10-*-iso*',
     & '*-helvetica-bold-o-*-10-*-iso*','6x13','*-courier-bold-r-*-14-*'
     & ,'*-times-*-r-*-24-*','*-times-*-r-*-18-*',
     & 2*'*-times-*-r-*-34-*','*-times-*-r-*-14-*',
     & '*-helvetica-*-r-*-14-*','*-helvetica-*-o-*-14-*',
     & '5x8','7x14b*','9x15b*','*-helvetica-*-r-*-12-*',
     & '*-helvetica-*-o-*-12-*','*-helvetica-*-r-*-10-*',
     & '*-helvetica-*-o-*-10-*','6x13','9x15b*','12x24','10x20',
     & 2*'12x24',3*'9x15b*','5x8','7x14b*','9x15b*',2*'7x14b*',3*'6x10',
     & '*-courier-bold-r-*-12-*-iso*','*-times-bold-r-*-20-*-iso*',
     & '*-times-bold-r-*-17-*-iso*',2*'*-times-bold-r-*-25-*-iso*',
     & '*-times-bold-r-*-12-*-iso*','*-helvetica-bold-r-*-12-*-iso*',
     & '*-helvetica-bold-o-*-12-*-iso*','5x7','7x13b*','8x13b*',
     & '*-helvetica-bold-r-*-10-*-iso*',
     & '*-helvetica-bold-o-*-10-*-iso*',
     & '*-helvetica-bold-r-*-8-*-iso*',
     & '*-helvetica-bold-o-*-8-*-iso*','6x10','*-courier-bold-r-*-12-*',
     & '*-times-*-r-*-24-*', '*-times-*-r-*-18-*',
     & 2*'*-times-*-r-*-34-*','*-times-*-r-*-12-*',
     & '*-helvetica-*-r-*-12-*','*-helvetica-*-o-*-12-*',
     & '5x7','7x13b*','8x13b*','*-helvetica-*-r-*-10-*',
     & '*-helvetica-*-o-*-10-*','*-helvetica-*-r-*-8-*',
     & '*-helvetica-*-o-*-8-*','6x10','9x15b*','12x24','10x20',
     & 2*'12x24',3*'9x15b*','5x7','7x13b*','8x13b*',2*'7x13b*',2*'5x7'/
      data lfont / 4,28,26,26,26,26,26,30,30,3,6,6,30,30,30,30 , 
     &             4,23,18,18,18,18,18,22,22,3,6,6,22,22,22,22 ,
     &             4, 6, 5, 5, 5, 5, 6, 6, 6,3,6,6, 6, 6, 4, 4 ,
     &             4,28,26,26,26,26,26,30,30,3,6,6,30,30,29,29 , 
     &             4,23,18,18,18,18,18,22,22,3,6,6,22,22,21,21 ,
     &             4, 6, 5, 5, 5, 5, 6, 6, 6,3,6,6, 6, 6, 3, 3 /
      save imagnif,iptifont
c
cc     & '*-courier-medium-r-*-12-*',
cc     & '-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1',
cc     & '-adobe-courier-bold-r-normal--17-120-100-100-m-100-iso8859-1',
cc     & '-adobe-times-bold-r-normal--24-240-75-75-p-132-iso8859-1',
cc     & '-adobe-times-bold-r-normal--18-180-75-75-p-99-iso8859-1',
cccc     '-misc-fixed-medium-r-normal--10-70-100-100-c-60-iso8859-1'
cccc     '-adobe-courier-medium-r-normal--10-100-75-75-m-60-iso8859-1'
cccc      -adobe-courier-medium-r-normal--11-80-100-100-m-60-iso8859-1
cccc      -adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1

      if (lapremierefois.eq.0.and.ipostscript.eq.1) then
        imagnif = 0
        if (nbpixx.le.1024.or.nbpixy.le.768) then
          iptifont = 1 + 3*nfontes_de_base
        else
          iptifont = 1
        endif
        iiii = ifonte + iptifont
        lafonte = fontes(iiii)(1:lfont(iiii))//char(0)
        iopt = 1
        call x11loadfont2(lafonte,iopt,irc)
        if (irc.eq.0) then
          if (albion) then
            print*,'Font',ifonte,': '
     &            ,lafonte(1:lfont(iiii)),' not found'
          else
            print*,'On n''a pas trouv la fonte',ifonte,' : '
     &            ,lafonte(1:lfont(iiii))
          endif
          iopt = 2
          ii = iiii+nfontes_de_base
          lafonte = fontes(ii)(1:lfont(ii))//char(0)
          call x11loadfont2(lafonte,iopt,irc)
          if (irc.eq.0) then
            ii = ii+nfontes_de_base
            iopt = 3
            lafonte = fontes(ii)(1:lfont(ii))//char(0)
            call x11loadfont2(lafonte,iopt,irc)
            if (irc.eq.0) then
              iopt = 4
              lafonte = '*'//char(0)
              call x11loadfont2(lafonte,iopt,irc)
            endif
          endif
        endif
        itrouve(iiii) = iopt-1
        ifonte_courante = ifonte
      else
        if (ifonte.eq.ifonte_courante.and.ipostscript.eq.1) return
        if (ifonte.lt.0.or.ifonte.gt.nfontes_de_base-1) then
          iopt = 1
        else
          iopt = ifonte
        endif
        if (ipostscript.eq.1) then
          ifonte_courante = iopt
          iiii = iopt+iptifont
          if (itrouve(iiii).eq.3) then
            lafonte = '*'//char(0)
          else
            ii = iiii+nfontes_de_base*itrouve(iiii)
            lafonte = fontes(ii)(1:lfont(ii))//char(0)
          endif
          iopt = 0
          call x11loadfont2(lafonte,iopt,irc)
          if (ifonte_courante.eq.5) then
            fafont = 1./0.65
            call x11magfont(fafont)
            imagnif = 1
          elseif (imagnif.ne.0) then
            fafont = 1.
            call x11magfont(fafont)
            imagnif = 0
          endif
        else
          iiii = ifonte_courante_ps
          tttt = taille_texte
          if (iopt.eq.0) then
            ifonte_courante_ps = 4
            taille_texte    = 0.25
          elseif(iopt.eq.1) then
            ifonte_courante_ps = 6
            taille_texte    = 0.35
          elseif (iopt.eq.2) then
            ifonte_courante_ps = 8
            taille_texte  = 0.65
          elseif (iopt.eq.3) then
            ifonte_courante_ps = 8
            taille_texte  = 0.45
          elseif(iopt.eq.4) then
            ifonte_courante_ps = 8
            taille_texte  = 1.
          elseif(iopt.eq.5) then
            ifonte_courante_ps = 8
            taille_texte  = 1./0.65
          elseif(iopt.eq.6) then
            ifonte_courante_ps = 8
            taille_texte  = 0.35
          elseif(iopt.eq.7) then
            ifonte_courante_ps = 25
            taille_texte    = 0.35
          elseif(iopt.eq.8) then
            ifonte_courante_ps = 14
            taille_texte    = 0.35
          elseif(iopt.eq.9) then
            ifonte_courante_ps = 4
            taille_texte    = 0.15
          endif
          taille_xloc = max(taille_y*0.667,taille_x)
          taille_yloc = max(taille_x*0.667,taille_y)
          taille_texte = taille_texte*amin1(taille_xloc,taille_yloc)/19.
cc          taille_texte = taille_texte*amin1(taille_x,taille_y)/19.
          if (iiii.ne.ifonte_courante_ps.or.tttt.ne.taille_texte)
     &    write(ilaser_file,1000) ifonte_courante_ps,angle_texte
     &                           ,nint(taille_texte*1000.)
c     &                           ,taille_texte
 1000     format(i2,f6.2,i6,' lf')
c 1000     format(i2,2f6.2,' lf')
        endif
      endif
      end

==> xd3d-8.3.1.tar.gz: xd3d-8.3.1/src/X/gslss.f <==
      subroutine gslss(ifonte)
      INCLUDE 'Parametres.f'
      character*132 lafonte,fontes(6*nfontes_de_base)
      integer lfont(6*nfontes_de_base)
      data fontes /
     & '6x13','*-courier-bold-r-*-17-*-iso*',
     & '*-times-bold-r-*-24-*-iso*','*-times-bold-r-*-18-*-iso*',
     & 2*'*-times-bold-r-*-34-*-iso*','*-times-bold-r-*-14-*-iso*',
     & '*-helvetica-medium-r-*-14-*-iso*'
     &,'*-helvetica-medium-o-*-14-*-iso*'
     & ,'5x8','7x14b*','9x15b*','*-helvetica-medium-r-*-12-*-iso*',
     & '*-helvetica-medium-o-*-12-*-iso*',
     & '*-helvetica-medium-r-*-10-*-iso*',
     & '*-helvetica-medium-o-*-10-*-iso*','6x13'
     &,'*-courier-bold-r-*-14-*'
     & ,'*-times-*-r-*-24-*','*-times-*-r-*-18-*',
     & 2*'*-times-*-r-*-34-*','*-times-*-r-*-14-*',
     & '*-helvetica-*-r-*-14-*','*-helvetica-*-o-*-14-*',
     & '5x8','7x14b*','9x15b*','*-helvetica-*-r-*-12-*',
     & '*-helvetica-*-o-*-12-*','*-helvetica-*-r-*-10-*',
     & '*-helvetica-*-o-*-10-*','6x13','9x15b*','12x24','10x20',
     & 2*'12x24',3*'9x15b*','5x8','7x14b*','9x15b*',2*'7x14b*',3*'6x10',
     & '*-courier-bold-r-*-12-*-iso*','*-times-bold-r-*-20-*-iso*',
     & '*-times-bold-r-*-17-*-iso*',2*'*-times-bold-r-*-25-*-iso*',
     & '*-times-bold-r-*-12-*-iso*','*-helvetica-medium-r-*-12-*-iso*',
     & '*-helvetica-medium-o-*-12-*-iso*','5x7','7x13b*','8x13b*',
     & '*-helvetica-medium-r-*-10-*-iso*',
     & '*-helvetica-medium-o-*-10-*-iso*',
     & '*-helvetica-medium-r-*-8-*-iso*',
     & '*-helvetica-medium-o-*-8-*-iso*','6x10'
     &,'*-courier-bold-r-*-12-*',
     & '*-times-*-r-*-24-*', '*-times-*-r-*-18-*',
     & 2*'*-times-*-r-*-34-*','*-times-*-r-*-12-*',
     & '*-helvetica-*-r-*-12-*','*-helvetica-*-o-*-12-*',
     & '5x7','7x13b*','8x13b*','*-helvetica-*-r-*-10-*',
     & '*-helvetica-*-o-*-10-*','*-helvetica-*-r-*-8-*',
     & '*-helvetica-*-o-*-8-*','6x10','9x15b*','12x24','10x20',
     & 2*'12x24',3*'9x15b*','5x7','7x13b*','8x13b*',2*'7x13b*',2*'5x7'/
      data lfont / 4,28,26,26,26,26,26,32,32,3,6,6,32,32,32,32 , 
     &             4,23,18,18,18,18,18,22,22,3,6,6,22,22,22,22 ,
     &             4, 6, 5, 5, 5, 5, 6, 6, 6,3,6,6, 6, 6, 4, 4 ,
     &             4,28,26,26,26,26,26,32,32,3,6,6,32,32,31,31 , 
     &             4,23,18,18,18,18,18,22,22,3,6,6,22,22,21,21 ,
     &             4, 6, 5, 5, 5, 5, 6, 6, 6,3,6,6, 6, 6, 3, 3 /
      save imagnif,iptifont
c
cc     & '*-courier-medium-r-*-12-*',
cc     & '-adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1',
cc     & '-adobe-courier-bold-r-normal--17-120-100-100-m-100-iso8859-1',
cc     & '-adobe-times-bold-r-normal--24-240-75-75-p-132-iso8859-1',
cc     & '-adobe-times-bold-r-normal--18-180-75-75-p-99-iso8859-1',
cccc     '-misc-fixed-medium-r-normal--10-70-100-100-c-60-iso8859-1'
cccc     '-adobe-courier-medium-r-normal--10-100-75-75-m-60-iso8859-1'
cccc      -adobe-courier-medium-r-normal--11-80-100-100-m-60-iso8859-1
cccc      -adobe-courier-medium-r-normal--12-120-75-75-m-70-iso8859-1

      if (lapremierefois.eq.0.and.ipostscript.eq.1) then
        imagnif = 0
        if (nbpixx.le.1024.or.nbpixy.le.768) then
          iptifont = 1 + 3*nfontes_de_base
        else
          iptifont = 1
        endif
        iiii = ifonte + iptifont
        lafonte = fontes(iiii)(1:lfont(iiii))//char(0)
        iopt = 1
        call x11loadfont2(lafonte,iopt,irc)
        if (irc.eq.0) then
          if (albion) then
            print*,'Font',ifonte,': '
     &            ,lafonte(1:lfont(iiii)),' not found'
          else
            print*,'On n''a pas trouv la fonte',ifonte,' : '
     &            ,lafonte(1:lfont(iiii))
          endif
          iopt = 2
          ii = iiii+nfontes_de_base
          lafonte = fontes(ii)(1:lfont(ii))//char(0)
          call x11loadfont2(lafonte,iopt,irc)
          if (irc.eq.0) then
            ii = ii+nfontes_de_base
            iopt = 3
            lafonte = fontes(ii)(1:lfont(ii))//char(0)
            call x11loadfont2(lafonte,iopt,irc)
            if (irc.eq.0) then
              iopt = 4
              lafonte = '*'//char(0)
              call x11loadfont2(lafonte,iopt,irc)
            endif
          endif
        endif
        itrouve(iiii) = iopt-1
        ifonte_courante = ifonte
      else
        if (ifonte.eq.ifonte_courante.and.ipostscript.eq.1) return
        if (ifonte.lt.0.or.ifonte.gt.nfontes_de_base-1) then
          iopt = 1
        else
          iopt = ifonte
        endif
        if (ipostscript.eq.1) then
          ifonte_courante = iopt
          iiii = iopt+iptifont
          if (itrouve(iiii).eq.3) then
            lafonte = '*'//char(0)
          else
            ii = iiii+nfontes_de_base*itrouve(iiii)
            lafonte = fontes(ii)(1:lfont(ii))//char(0)
          endif
          iopt = 0
          call x11loadfont2(lafonte,iopt,irc)
          if (ifonte_courante.eq.5) then
            fafont = 1./0.65
            call x11magfont(fafont)
            imagnif = 1
          elseif (imagnif.ne.0) then
            fafont = 1.
            call x11magfont(fafont)
            imagnif = 0
          endif
        else
          iiii = ifonte_courante_ps
          tttt = taille_texte
          if (iopt.eq.0) then
            ifonte_courante_ps = 4
            taille_texte    = 0.25
          elseif(iopt.eq.1) then
            ifonte_courante_ps = 6
            taille_texte    = 0.35
          elseif (iopt.eq.2) then
            ifonte_courante_ps = 8
            taille_texte  = 0.65
          elseif (iopt.eq.3) then
            ifonte_courante_ps = 8
            taille_texte  = 0.45
          elseif(iopt.eq.4) then
            ifonte_courante_ps = 8
            taille_texte  = 1.
          elseif(iopt.eq.5) then
            ifonte_courante_ps = 8
            taille_texte  = 1./0.65
          elseif(iopt.eq.6) then
            ifonte_courante_ps = 8
            taille_texte  = 0.35
          elseif(iopt.eq.7) then
            ifonte_courante_ps = 25
            taille_texte    = 0.35
          elseif(iopt.eq.8) then
            ifonte_courante_ps = 14
            taille_texte    = 0.35
          elseif(iopt.eq.9) then
            ifonte_courante_ps = 4
            taille_texte    = 0.15
          endif
          taille_xloc = max(taille_y*0.667,taille_x)
          taille_yloc = max(taille_x*0.667,taille_y)
          taille_texte = taille_texte*amin1(taille_xloc,taille_yloc)/19.
cc          taille_texte = taille_texte*amin1(taille_x,taille_y)/19.
          if (iiii.ne.ifonte_courante_ps.or.tttt.ne.taille_texte)
     &    write(ilaser_file,1000) ifonte_courante_ps,angle_texte
     &                           ,nint(taille_texte*1000.)
c     &                           ,taille_texte
 1000     format(i2,f6.2,i6,' lf')
c 1000     format(i2,2f6.2,' lf')
        endif
      endif
      end
